@@ -7,12 +7,14 @@
 
 add.label <- function(x, column,
                       xpos, ypos, just, fs.lr, ff.lr, col,
+                      fontfamily,
                       ...) {
   ##
   pushViewport(viewport(layout.pos.col = column, ...))
   ##
   grid.text(x, x = xpos, y = ypos, just = just,
-            gp = gpar(fontsize = fs.lr, fontface = ff.lr, col = col))
+            gp = gpar(fontsize = fs.lr, fontface = ff.lr, col = col,
+                      fontfamily = fontfamily))
   ##
   popViewport()
   ##
@@ -36,7 +38,8 @@ add.text <- function(x, column, ...) {
 
 
 add.xlab <- function(x, column, xlab, xlab.add, newline.xlab,
-                     xpos, ypos, fs.xlab, ff.xlab) {
+                     xpos, ypos, fs.xlab, ff.xlab,
+                     fontfamily) {
   ##
   pushViewport(viewport(layout.pos.col = column, xscale = x$range))
   ##
@@ -46,14 +49,16 @@ add.xlab <- function(x, column, xlab, xlab.add, newline.xlab,
             x = unit(xpos, "native"),
             y = unit(ypos, "lines"),
             just = "center",
-            gp = gpar(fontsize = fs.xlab, fontface = ff.xlab))
+            gp = gpar(fontsize = fs.xlab, fontface = ff.xlab,
+                      fontfamily = fontfamily))
   ##
   if (newline.xlab)
     grid.text(xlab.add,
               x = unit(xpos, "native"),
               y = unit(ypos - 1, "lines"),
               just = "center",
-              gp = gpar(fontsize = fs.xlab, fontface = ff.xlab))
+              gp = gpar(fontsize = fs.xlab, fontface = ff.xlab,
+                        fontfamily = fontfamily))
   ##
   popViewport()
   ##
@@ -62,7 +67,7 @@ add.xlab <- function(x, column, xlab, xlab.add, newline.xlab,
 
 
 draw.axis <- function(x, column, yS, log.xaxis, at, label,
-                      fs.axis, ff.axis, lwd,
+                      fs.axis, ff.axis, fontfamily, lwd,
                       xlim, notmiss.xlim) {
   ##
   ## Function to draw x-axis
@@ -128,19 +133,23 @@ draw.axis <- function(x, column, yS, log.xaxis, at, label,
       at <- log(at)
     }
     grid.xaxis(at = at, label = label,
-               gp = gpar(fontsize = fs.axis, fontface = ff.axis, lwd = lwd))
+               gp = gpar(fontsize = fs.axis, fontface = ff.axis,
+                         fontfamily = fontfamily, lwd = lwd))
   }
   else {
     if (is.null(at))
-      grid.xaxis(gp = gpar(fontsize = fs.axis, fontface = ff.axis, lwd = lwd))
+      grid.xaxis(gp = gpar(fontsize = fs.axis, fontface = ff.axis,
+                           fontfamily = fontfamily, lwd = lwd))
     else
       if ((length(label) == 1 && is.logical(label) && label) |
           (length(label) >= 1 & !is.logical(label)))
         grid.xaxis(at = at, label = label,
-                   gp = gpar(fontsize = fs.axis, fontface = ff.axis, lwd = lwd))
+                   gp = gpar(fontsize = fs.axis, fontface = ff.axis,
+                             fontfamily = fontfamily, lwd = lwd))
     else
       grid.xaxis(at = at,
-                 gp = gpar(fontsize = fs.axis, fontface = ff.axis, lwd = lwd))
+                 gp = gpar(fontsize = fs.axis, fontface = ff.axis,
+                           fontfamily = fontfamily, lwd = lwd))
   }
   ##
   popViewport()
@@ -329,9 +338,11 @@ draw.forest <- function(x, column) {
 draw.lines <- function(x, column,
                        ref, TE.fixed, TE.random,
                        overall, comb.fixed, comb.random, prediction,
-                       ylim.fixed, ylim.random, ylim.ref,
+                       ymin.fixed, ymin.random, ymin.ref, ymax,
 		       lwd, lty.fixed, lty.random, col.fixed, col.random,
-                       min, max) {
+                       min, max,
+                       lower.equi, upper.equi,
+                       lty.equi, col.equi, fill.equi) {
   ##
   if (min > max) {
     min <- x$range[2]
@@ -344,11 +355,30 @@ draw.lines <- function(x, column,
   ##
   pushViewport(viewport(layout.pos.col = column, xscale = x$range))
   ##
+  ## Add equivalence region
+  ##
+  if ((!is.na(lower.equi) && (min <= lower.equi & lower.equi <= max)) &
+      (!is.na(upper.equi) && (min <= upper.equi & upper.equi <= max)))
+    grid.polygon(x = unit(c(lower.equi, upper.equi,
+                            upper.equi, lower.equi), "native"),
+                 y = unit(c(ymin.ref, ymin.ref, ymax, ymax), "lines"),
+                 gp = gpar(lwd = lwd, col = fill.equi, fill = fill.equi))
+  ##
+  if (!is.na(lower.equi) && (min <= lower.equi & lower.equi <= max))
+    grid.lines(x = unit(lower.equi, "native"),
+               y = unit(c(ymin.ref, ymax), "lines"),
+               gp = gpar(lwd = lwd, col = col.equi, lty = lty.equi))
+  ##
+  if (!is.na(upper.equi) && (min <= upper.equi & upper.equi <= max))
+    grid.lines(x = unit(upper.equi, "native"),
+               y = unit(c(ymin.ref, ymax), "lines"),
+               gp = gpar(lwd = lwd, col = col.equi, lty = lty.equi))
+  ##
   ## Reference line:
   ##
   if (!is.na(ref) && (min <= ref & ref <= max))
     grid.lines(x = unit(ref, "native"),
-               y = unit(ylim.ref, "lines"),
+               y = unit(c(ymin.ref, ymax), "lines"),
                gp = gpar(lwd = lwd))
   ##
   ## Line for fixed effect estimate:
@@ -357,7 +387,7 @@ draw.lines <- function(x, column,
     if (min <= TE.fixed & TE.fixed <= max)
       if (!is.null(lty.fixed))
         grid.lines(x = unit(TE.fixed, "native"),
-                   y = unit(ylim.fixed, "lines"),
+                   y = unit(c(ymin.fixed, ymax), "lines"),
                    gp = gpar(lty = lty.fixed, lwd = lwd, col = col.fixed))
   ##
   ## Line for random effects estimate:
@@ -366,7 +396,7 @@ draw.lines <- function(x, column,
     if (min <= TE.random & TE.random <= max)
       if (!is.null(lty.random) & !is.na(TE.random))
         grid.lines(x = unit(TE.random, "native"),
-                   y = unit(ylim.random, "lines"),
+                   y = unit(c(ymin.random, ymax), "lines"),
                    gp = gpar(lty = lty.random, lwd = lwd, col = col.random))
   ##
   popViewport()
@@ -375,7 +405,8 @@ draw.lines <- function(x, column,
 }
 
 
-formatcol <- function(x, y, rows, just = "right", settings) {
+formatcol <- function(x, y, rows, just = "right", settings,
+                      fontfamily) {
   ##
   if (just == "left")
     xpos <- 0
@@ -389,7 +420,8 @@ formatcol <- function(x, y, rows, just = "right", settings) {
                        textGrob, x = xpos, just = just,
                        gp = gpar(
                          fontsize = settings$fs.study,
-                         fontface = settings$ff.study)
+                         fontface = settings$ff.study,
+                         fontfamily = fontfamily)
                        ),
               rows = rows)
   ##
@@ -399,7 +431,8 @@ formatcol <- function(x, y, rows, just = "right", settings) {
                               x = xpos, just = just,
                               gp = gpar(
                                 fontsize = settings$fs.heading,
-                                fontface = settings$ff.heading)
+                                fontface = settings$ff.heading,
+                                fontfamily = fontfamily)
                               )
   ##
   ## Fixed effect estimate:
@@ -408,7 +441,8 @@ formatcol <- function(x, y, rows, just = "right", settings) {
                               x = xpos, just = just,
                               gp = gpar(
                                 fontsize = settings$fs.fixed,
-                                fontface = settings$ff.fixed)
+                                fontface = settings$ff.fixed,
+                                fontfamily = fontfamily)
                               )
   ##
   ## Random effects estimate:
@@ -417,7 +451,8 @@ formatcol <- function(x, y, rows, just = "right", settings) {
                               x = xpos, just = just,
                               gp = gpar(
                                 fontsize = settings$fs.random,
-                                fontface = settings$ff.random)
+                                fontface = settings$ff.random,
+                                fontfamily = fontfamily)
                               )
   ##
   ## Prediction interval:
@@ -426,7 +461,8 @@ formatcol <- function(x, y, rows, just = "right", settings) {
                               x = xpos, just = just,
                               gp = gpar(
                                 fontsize = settings$fs.predict,
-                                fontface = settings$ff.predict)
+                                fontface = settings$ff.predict,
+                                fontfamily = fontfamily)
                               )
   ##
   if (settings$by)
@@ -440,6 +476,7 @@ formatcol <- function(x, y, rows, just = "right", settings) {
                                         gpar(
                                           fontsize = settings$fs.fixed,
                                           fontface = settings$ff.fixed,
+                                          fontfamily = fontfamily,
                                           col = settings$col.by)
                                       )
       ##
@@ -451,6 +488,7 @@ formatcol <- function(x, y, rows, just = "right", settings) {
                                                gpar(
                                                  fontsize = settings$fs.random,
                                                  fontface = settings$ff.random,
+                                                 fontfamily = fontfamily,
                                                  col = settings$col.by)
                                              )
     }
@@ -469,28 +507,30 @@ removeNULL <- function(x, names, varname) {
 }
 
 
-tg <- function(x, xpos, just, fs, ff, col) {
+tg <- function(x, xpos, just, fs, ff, fontfamily, col) {
   if (missing(col))
     res <- textGrob(x,
                     x = xpos, just = just,
-                    gp = gpar(fontsize = fs, fontface = ff))
+                    gp = gpar(fontsize = fs, fontface = ff,
+                              fontfamily = fontfamily))
   else
     res <- textGrob(x,
                     x = xpos, just = just,
                     gp = gpar(fontsize = fs, fontface = ff,
+                              fontfamily = fontfamily,
                               col = col))
   ##
   res
 }
 
 
-tgl <- function(x, xpos, just, fs, ff, rows = 1, col) {
+tgl <- function(x, xpos, just, fs, ff, fontfamily, rows = 1, col) {
   ##
   if (missing(col))
-    res <- list(labels = list(tg(x, xpos, just, fs, ff)),
+    res <- list(labels = list(tg(x, xpos, just, fs, ff, fontfamily)),
                 rows = rows)
   else
-    res <- list(labels = list(tg(x, xpos, just, fs, ff, col)),
+    res <- list(labels = list(tg(x, xpos, just, fs, ff, fontfamily, col)),
                 rows = rows)
   ##
   res
