@@ -47,9 +47,15 @@
 #'   Knapp should be used to adjust test statistics and confidence
 #'   intervals.
 #' @param method.tau A character string indicating which method is
-#'   used to estimate the between-study variance \eqn{\tau^2}, see
-#'   Details.
-#' @param tau.preset Prespecified value for the square-root of the
+#'   used to estimate the between-study variance \eqn{\tau^2} and its
+#'   square root \eqn{\tau}. Either \code{"DL"}, \code{"PM"},
+#'   \code{"REML"}, \code{"ML"}, \code{"HS"}, \code{"SJ"},
+#'   \code{"HE"}, or \code{"EB"}, can be abbreviated.
+#' @param method.tau.ci A character string indicating which method is
+#'   used to estimate the confidence interval of \eqn{\tau^2} and
+#'   \eqn{\tau}. Either \code{"QP"}, \code{"BJ"}, or \code{"J"}, or
+#'   \code{""}, can be abbreviated.
+#' @param tau.preset Prespecified value for the square root of the
 #'   between-study variance \eqn{\tau^2}.
 #' @param TE.tau Overall treatment effect used to estimate the
 #'   between-study variance tau-squared.
@@ -86,8 +92,8 @@
 #'   \code{incr} to studies with zero events should result in a
 #'   warning.
 #' @param control An optional list to control the iterative process to
-#'   estimate the between-study variance tau^2. This argument is
-#'   passed on to \code{\link[metafor]{rma.uni}} or
+#'   estimate the between-study variance \eqn{\tau^2}. This argument
+#'   is passed on to \code{\link[metafor]{rma.uni}} or
 #'   \code{\link[metafor]{rma.glmm}}, respectively.
 #' @param \dots Additional arguments passed on to
 #'   \code{\link[metafor]{rma.glmm}} function.
@@ -145,8 +151,7 @@
 #' \subsection{Estimation of between-study variance}{
 #' 
 #' The following methods to estimate the between-study variance
-#' \eqn{\tau^2} (argument \code{method.tau}) are available for the
-#' inverse variance method:
+#' \eqn{\tau^2} are available for the inverse variance method:
 #' \itemize{
 #' \item DerSimonian-Laird estimator (\code{method.tau = "DL"})
 #' \item Paule-Mandel estimator (\code{method.tau = "PM"})
@@ -163,6 +168,23 @@
 #' GLMMs.
 #' }
 #' 
+#' \subsection{Confidence interval for the between-study variance}{
+#'
+#' The following methods to calculate a confidence interval for
+#' \eqn{\tau^2} and \eqn{\tau} are available.
+#' \tabular{ll}{
+#' \bold{Argument}\tab \bold{Method} \cr 
+#' \code{method.tau.ci = "J"}\tab Method by Jackson \cr
+#' \code{method.tau.ci = "BJ"}\tab Method by Biggerstaff and Jackson \cr
+#' \code{method.tau.ci = "QP"}\tab Q-Profile method
+#' }
+#' See \code{\link{metagen}} for more information on these
+#' methods. For GLMMs, no confidence intervals for \eqn{\tau^2} and
+#' \eqn{\tau} are calculated. Likewise, no confidence intervals for
+#' \eqn{\tau^2} and \eqn{\tau} are calculated if \code{method.tau.ci =
+#' ""}. 
+#' }
+#' 
 #' \subsection{Hartung-Knapp method}{
 #' 
 #' Hartung and Knapp (2001a,b) proposed an alternative method for
@@ -240,8 +262,8 @@
 #' \item{sm, incr, allincr, addincr, method.ci,}{As defined above.}
 #' \item{level, level.comb,}{As defined above.}
 #' \item{comb.fixed, comb.random,}{As defined above.}
-#' \item{hakn, method.tau, tau.preset, TE.tau, null.effect,}{As
-#'   defined above.}
+#' \item{hakn, method.tau, method.tau.ci,}{As defined above.}
+#' \item{tau.preset, TE.tau, null.hypothesis,}{As defined above.}
 #' \item{method.bias, tau.common, title, complab, outclab,}{As defined
 #'   above.}
 #' \item{byvar, bylab, print.byvar, byseparator, warn}{As defined
@@ -280,10 +302,22 @@
 #'   (only if \code{method = "GLMM"}).}
 #' \item{df.Q.LRT}{Degrees of freedom for likelihood-ratio test}
 #' \item{pval.Q.LRT}{P-value of likelihood-ratio test.}
-#' \item{tau}{Square-root of between-study variance.}
-#' \item{se.tau2}{Standard error of between-study variance.}
-#' \item{C}{Scaling factor utilised internally to calculate common
-#'   tau-squared across subgroups.}
+#' \item{tau2}{Between-study variance \eqn{\tau^2}.}
+#' \item{se.tau2}{Standard error of \eqn{\tau^2}.}
+#' \item{lower.tau2, upper.tau2}{Lower and upper limit of confidence
+#'   interval for \eqn{\tau^2}.}
+#' \item{tau}{Square-root of between-study variance \eqn{\tau}.}
+#' \item{lower.tau, upper.tau}{Lower and upper limit of confidence
+#'   interval for \eqn{\tau}.}
+#' \item{H}{Heterogeneity statistic H.}
+#' \item{lower.H, upper.H}{Lower and upper confidence limit for
+#'  heterogeneity statistic H.}
+#' \item{I2}{Heterogeneity statistic I\eqn{^2}.}
+#' \item{lower.I2, upper.I2}{Lower and upper confidence limit for
+#'   heterogeneity statistic I\eqn{^2}.}
+#' \item{Rb}{Heterogeneity statistic R\eqn{_b}.}
+#' \item{lower.Rb, upper.Rb}{Lower and upper confidence limit for
+#'   heterogeneity statistic R\eqn{_b}.}
 #' \item{method}{A character string indicating method used for
 #'   pooling: \code{"Inverse"}}
 #' \item{df.hakn}{Degrees of freedom for test of treatment effect for
@@ -353,17 +387,15 @@
 #'   not missing.}
 #' \item{tau.w}{Square-root of between-study variance within subgroups
 #'   - if \code{byvar} is not missing.}
-#' \item{C.w}{Scaling factor utilised internally to calculate common
-#'   tau-squared across subgroups - if \code{byvar} is not missing.}
 #' \item{H.w}{Heterogeneity statistic H within subgroups - if
 #'   \code{byvar} is not missing.}
-#' \item{lower.H.w, upper.H.w}{Lower and upper confidence limti for
+#' \item{lower.H.w, upper.H.w}{Lower and upper confidence limit for
 #'   heterogeneity statistic H within subgroups - if \code{byvar} is
 #'   not missing.}
-#' \item{I2.w}{Heterogeneity statistic I2 within subgroups - if
+#' \item{I2.w}{Heterogeneity statistic I\eqn{^2} within subgroups - if
 #'   \code{byvar} is not missing.}
-#' \item{lower.I2.w, upper.I2.w}{Lower and upper confidence limti for
-#'   heterogeneity statistic I2 within subgroups - if \code{byvar} is
+#' \item{lower.I2.w, upper.I2.w}{Lower and upper confidence limit for
+#'   heterogeneity statistic I\eqn{^2} within subgroups - if \code{byvar} is
 #'   not missing.}
 #' \item{incr.event}{Increment added to number of events.}
 #' \item{keepdata}{As defined above.}
@@ -491,10 +523,8 @@ metarate <- function(event, time, studlab,
                      comb.random = gs("comb.random"),
                      ##
                      hakn = gs("hakn"),
-                     method.tau =
-                       ifelse(!is.na(charmatch(tolower(method), "glmm",
-                                               nomatch = NA)),
-                              "ML", gs("method.tau")),
+                     method.tau,
+                     method.tau.ci = if (method.tau == "DL") "J" else "QP",
                      tau.preset = NULL, TE.tau = NULL,
                      tau.common = gs("tau.common"),
                      ##
@@ -535,8 +565,10 @@ metarate <- function(event, time, studlab,
   chklogical(comb.random)
   ##
   chklogical(hakn)
-  method.tau <- setchar(method.tau,
-                        c("DL", "PM", "REML", "ML", "HS", "SJ", "HE", "EB"))
+  if (missing(method.tau))
+    method.tau <- if (method == "GLMM") "ML" else gs("method.tau")
+  method.tau <- setchar(method.tau, .settings$meth4tau)
+  method.tau.ci <- setchar(method.tau.ci, .settings$meth4tau.ci)
   chklogical(tau.common)
   ##
   chklogical(prediction)
@@ -570,10 +602,12 @@ metarate <- function(event, time, studlab,
   chklogical(warn)
   ##
   if (is.glmm & sm != "IRLN")
-    stop("Generalised linear mixed models only possible with argument 'sm = \"IRLN\"'.")
+    stop("Generalised linear mixed models only possible with ",
+         "argument 'sm = \"IRLN\"'.")
   ##
   if (is.glmm & method.tau != "ML")
-    stop("Generalised linear mixed models only possible with argument 'method.tau = \"ML\"'.")
+    stop("Generalised linear mixed models only possible with ",
+         "argument 'method.tau = \"ML\"'.")
   
   
   ##
@@ -864,7 +898,7 @@ metarate <- function(event, time, studlab,
                comb.random = comb.random,
                ##
                hakn = hakn,
-               method.tau = method.tau,
+               method.tau = method.tau, method.tau.ci = method.tau.ci,
                tau.preset = tau.preset,
                TE.tau = TE.tau,
                tau.common = FALSE,
@@ -886,8 +920,8 @@ metarate <- function(event, time, studlab,
   ##
   if (by & tau.common) {
     ## Estimate common tau-squared across subgroups
-    hcc <- hetcalc(TE, seTE, method.tau, TE.tau,
-                   level.comb, byvar, control)
+    hcc <- hetcalc(TE, seTE, method.tau, "",
+                   TE.tau, level.comb, byvar, control)
   }
   
   
@@ -961,7 +995,6 @@ metarate <- function(event, time, studlab,
     res$zval.random <- ci.r$z
     res$pval.random <- ci.r$p
     ##
-    res$se.tau2 <- NA
     ci.p <- predict.rma(glmm.random, level = 100 * level.predict)
     res$seTE.predict <- NA
     res$lower.predict <- ci.p$cr.lb
@@ -979,8 +1012,23 @@ metarate <- function(event, time, studlab,
     res$df.Q.LRT   <- res$df.Q
     res$pval.Q.LRT <- pvalQ(res$Q.LRT, res$df.Q.LRT)
     ##
-    if (k > 1)
+    if (k > 1) {
       res$tau <- sqrt(glmm.random$tau2)
+      res$tau2 <- glmm.random$tau2
+      res$se.tau2 <- glmm.random$se.tau2
+    }
+    else
+      res$se.tau2 <- NA
+    ##
+    res$lower.tau2 <- NA
+    res$upper.tau2 <- NA
+    ##
+    res$lower.tau <- NA
+    res$upper.tau <- NA
+    ##
+    res$method.tau.ci <- ""
+    res$sign.lower.tau <- ""
+    res$sign.upper.tau <- ""
     ##
     res$H <- sqrt(glmm.random$H2)
     res$lower.H <- NA
@@ -990,6 +1038,10 @@ metarate <- function(event, time, studlab,
     res$lower.I2 <- NA
     res$upper.I2 <- NA
     ##
+    res$Rb <- NA
+    res$lower.Rb <- NA
+    res$upper.Rb <- NA
+    ##
     res$.glmm.fixed  <- glmm.fixed
     res$.glmm.random <- glmm.random
     res$version.metafor <- packageDescription("metafor")$Version
@@ -1022,23 +1074,33 @@ metarate <- function(event, time, studlab,
     ##
     if (!tau.common) {
       res <- c(res, subgroup(res))
-      res$tau.resid <- NA
+      res$tau2.resid <- res$lower.tau2.resid <- res$upper.tau2.resid <- NA
+      res$tau.resid <- res$lower.tau.resid <- res$upper.tau.resid <- NA
     }
     else if (!is.null(tau.preset)) {
       res <- c(res, subgroup(res, tau.preset))
-      res$tau.resid <- NA
+      res$tau2.resid <- res$lower.tau2.resid <- res$upper.tau2.resid <- NA
+      res$tau.resid <- res$lower.tau.resid <- res$upper.tau.resid <- NA
     }
     else {
       if (is.glmm) {
         res <- c(res, subgroup(res, NULL,
                                factor(res$byvar, bylevs(res$byvar)), ...))
-        res$tau.resid <- NA
+        res$tau2.resid <- res$lower.tau2.resid <- res$upper.tau2.resid <- NA
+        res$tau.resid <- res$lower.tau.resid <- res$upper.tau.resid <- NA
       }
       else {
         res <- c(res, subgroup(res, hcc$tau))
         res$Q.w.random <- hcc$Q
         res$df.Q.w.random <- hcc$df.Q
+        res$tau2.resid <- hcc$tau2
+        res$lower.tau2.resid <- hcc$lower.tau2
+        res$upper.tau2.resid <- hcc$upper.tau2
         res$tau.resid <- hcc$tau
+        res$lower.tau.resid <- hcc$lower.tau
+        res$upper.tau.resid <- hcc$upper.tau
+        res$sign.lower.tau.resid <- hcc$sign.lower.tau
+        res$sign.upper.tau.resid <- hcc$sign.upper.tau
       }
     }
     ##
