@@ -44,13 +44,16 @@
 #' \code{tau.common} \tab FALSE \tab common between-study variance in
 #'   subgroups \cr
 #' \code{MH.exact} \tab FALSE \tab exact Mantel-Haenszel method \cr
-#' \code{RR.cochrane} \tab TRUE \tab calculation of risk ratios \cr
+#' \code{RR.Cochrane} \tab TRUE \tab calculation of risk ratios \cr
+#' \code{Q.Cochrane} \tab TRUE \tab calculation of heterogeneity statistic \cr
 #' \code{layout} \tab "RevMan5" \tab layout for forest plots \cr
 #' \code{test.overall} \tab TRUE \tab print information on test of
 #'   overall effect \cr
 #' \code{digits.I2} \tab 0 \tab number of digits for I-squared measure
 #'   \cr
-#' \code{digits.tau2} \tab 0 \tab number of digits for tau-squared \cr
+#' \code{digits.tau2} \tab 2 \tab number of digits for tau-squared \cr
+#' \code{digits.tau} \tab 4 \tab number of digits for square root of
+#'   tau-squared \cr
 #' \code{CIbracket}, \tab "[" \tab \cr
 #' \code{CIseparator} \tab ", " \tab print confidence intervals as
 #'   "\code{[., .]}"
@@ -66,7 +69,11 @@
 #'   \cr
 #' \code{CIbracket}, \tab "(" \tab \cr
 #' \code{CIseparator} \tab "-" \tab print confidence intervals as
-#'   "\code{(.-.)}"
+#'   "\code{(.-.)}" \cr
+#' \code{zero.pval}, \tab TRUE \tab print p-values with leading zero
+#' \cr
+#' \code{JAMA.pval}, \tab TRUE \tab round p-values to three digits
+#'   (for 0.001 < p \eqn{\le} 0.01) or two digits (p > 0.01)
 #' }
 #' 
 #' A list of all arguments with current settings is printed using the
@@ -177,6 +184,7 @@ settings.meta <- function(...) {
   res$sm4bin <- res$sm4cont <- res$sm4cor <- res$sm4inc <-
     res$sm4mean <- res$sm4prop <- res$sm4rate <- NULL
   res$ci4prop <- NULL
+  res$meth4tau <- res$meth4tau.ci <- NULL
   res$argslist <- NULL
   res$Wan2014.Table1 <- res$Wan2014.Table2 <- NULL
   
@@ -353,6 +361,7 @@ settings.meta <- function(...) {
     catarg("digits.zval    ")
     catarg("digits.Q       ")
     catarg("digits.tau2    ")
+    catarg("digits.tau     ")
     catarg("digits.H       ")
     catarg("digits.I2      ")
     catarg("digits.prop    ")
@@ -361,10 +370,13 @@ settings.meta <- function(...) {
     catarg("digits.pval.Q  ")
     catarg("scientific.pval")
     catarg("big.mark       ")
+    catarg("zero.pval      ")
+    catarg("JAMA.pval      ")
     catarg("print.I2       ")
     catarg("print.H        ")
     catarg("print.Rb       ")
     catarg("text.tau2      ")
+    catarg("text.tau       ")
     catarg("text.I2        ")
     catarg("text.Rb        ")
     ##
@@ -393,7 +405,8 @@ settings.meta <- function(...) {
     catarg("method     ")
     catarg("allstudies ")
     catarg("MH.exact   ")
-    catarg("RR.cochrane")
+    catarg("RR.Cochrane")
+    catarg("Q.Cochrane ")
     catarg("model.glmm ")
     catarg("print.CMH  ")
     ##
@@ -447,6 +460,7 @@ settings.meta <- function(...) {
     setOption("digits.zval", 2)
     setOption("digits.Q", 2)
     setOption("digits.tau2", 4)
+    setOption("digits.tau", 4)
     setOption("digits.H", 2)
     setOption("digits.I2", 1)
     setOption("digits.prop", 4)
@@ -455,10 +469,13 @@ settings.meta <- function(...) {
     setOption("digits.pval.Q", 4)
     setOption("scientific.pval", FALSE)
     setOption("big.mark", "")
+    setOption("zero.pval", TRUE)
+    setOption("JAMA.pval", FALSE)
     setOption("print.I2", TRUE)
     setOption("print.H", TRUE)
     setOption("print.Rb", FALSE)
     setOption("text.tau2", "tau^2")
+    setOption("text.tau", "tau")
     setOption("text.I2", "I^2")
     setOption("text.Rb", "Rb")
     ##
@@ -468,7 +485,8 @@ settings.meta <- function(...) {
     setOption("addincr", FALSE)
     setOption("allstudies", FALSE)
     setOption("MH.exact", FALSE)
-    setOption("RR.cochrane", FALSE)
+    setOption("RR.Cochrane", FALSE)
+    setOption("Q.Cochrane", TRUE)
     setOption("model.glmm", "UM.FS")
     setOption("print.CMH", FALSE)
     ##
@@ -505,16 +523,16 @@ settings.meta <- function(...) {
     ##
     if (setting == "RevMan5") {
       specificSetting(args = c("hakn", "method.tau", "tau.common",
-                               "MH.exact", "RR.cochrane",
+                               "MH.exact", "RR.Cochrane", "Q.Cochrane",
                                "layout", "test.overall",
                                "test.subgroup", "test.effect.subgroup",
-                               "digits.I2", "digits.tau2",
+                               "digits.I2", "digits.tau2", "digits.tau",
                                "CIbracket", "CIseparator"),
                       new = list(FALSE, "DL", FALSE,
-                                 FALSE, TRUE,
+                                 FALSE, TRUE, TRUE,
                                  "RevMan5", TRUE,
                                  TRUE, TRUE,
-                                 0, 2,
+                                 0, 2, 4,
                                  "[", ", "),
                       setting = "RevMan 5 settings")
     }
@@ -522,25 +540,31 @@ settings.meta <- function(...) {
     else if (setting == "JAMA") {
       specificSetting(args = c("layout", "test.overall",
                                "test.subgroup", "test.effect.subgroup",
-                               "digits.I2",
-                               "CIbracket", "CIseparator"),
+                               "digits.I2", "digits.pval",
+                               "CIbracket", "CIseparator",
+                               "zero.pval", "JAMA.pval"),
                       new = list("JAMA", TRUE,
                                  FALSE, FALSE,
-                                 0,
-                                 "(", "-"),
+                                 0, 3,
+                                 "(", "-",
+                                 FALSE, TRUE),
                       setting = "JAMA settings")
     }
     ##
     else if (setting == "IQWiG4.2") {
-      specificSetting(args = c("hakn", "method.tau", "RR.cochrane"),
-                      new = list(TRUE, "PM", FALSE),
+      specificSetting(args = c("hakn", "method.tau", "RR.Cochrane",
+                               "Q.Cochrane"),
+                      new = list(TRUE, "PM", FALSE,
+                                 FALSE),
                       setting = "IQWiG 4.2 settings")
     }
     ##
     else if (setting == "meta4") {
-      specificSetting(args = c("hakn", "method.tau", "RR.cochrane",
+      specificSetting(args = c("hakn", "method.tau",
+                               "RR.Cochrane", "Q.Cochrane",
                                "CIbracket", "CIseparator"),
-                      new = list(FALSE, "DL", FALSE,
+                      new = list(FALSE, "DL",
+                                 FALSE, TRUE,
                                  "[", "; "),
                       setting = "settings from R package meta (version 4.y-z and older)")
     }
@@ -578,6 +602,7 @@ settings.meta <- function(...) {
     iddigits.zval <- argid(names, "digits.zval")
     iddigits.Q <- argid(names, "digits.Q") 
     iddigits.tau2 <- argid(names, "digits.tau2")
+    iddigits.tau <- argid(names, "digits.tau")
     iddigits.H <- argid(names, "digits.H") 
     iddigits.I2 <- argid(names, "digits.I2")
     iddigits.prop <- argid(names, "digits.prop")
@@ -586,10 +611,13 @@ settings.meta <- function(...) {
     iddigits.pval.Q <- argid(names, "digits.pval.Q")
     idscientific.pval <- argid(names, "scientific.pval")
     idbig.mark <- argid(names, "big.mark")
+    idzero.pval <- argid(names, "zero.pval")
+    idJAMA.pval <- argid(names, "JAMA.pval")
     idprint.I2 <- argid(names, "print.I2")
     idprint.H <- argid(names, "print.H")
     idprint.Rb <- argid(names, "print.Rb")
     idtext.tau2 <- argid(names, "text.tau2")
+    idtext.tau <- argid(names, "text.tau")
     idtext.I2 <- argid(names, "text.I2")
     idtext.Rb <- argid(names, "text.Rb")
     ##
@@ -600,7 +628,8 @@ settings.meta <- function(...) {
     idaddincr <- argid(names, "addincr")
     idallstudies <- argid(names, "allstudies")
     idMH.exact <- argid(names, "MH.exact")
-    idRR.cochrane <- argid(names, "RR.cochrane")
+    idRR.Cochrane <- argid(names, "RR.Cochrane")
+    idQ.Cochrane <- argid(names, "Q.Cochrane")
     idmodel.glmm <- argid(names, "model.glmm")
     idprint.CMH <- argid(names, "print.CMH")
     ##
@@ -658,8 +687,7 @@ settings.meta <- function(...) {
     }
     if (!is.na(idmethod.tau)) {
       method.tau <- args[[idmethod.tau]]
-      method.tau <- setchar(method.tau,
-                            c("DL", "PM", "REML", "ML", "HS", "SJ", "HE", "EB"))
+      method.tau <- setchar(method.tau, .settings$meth4tau)
       setOption("method.tau", method.tau)
     }
     if (!is.na(idtau.common)) {
@@ -762,6 +790,11 @@ settings.meta <- function(...) {
       chknumeric(digits.tau2, min = 0, single = TRUE)
       setOption("digits.tau2", digits.tau2)
     }
+    if (!is.na(iddigits.tau)) {
+      digits.tau <- args[[iddigits.tau]]
+      chknumeric(digits.tau, min = 0, single = TRUE)
+      setOption("digits.tau", digits.tau)
+    }
     if (!is.na(iddigits.H)) {
       digits.H <- args[[iddigits.H]]
       chknumeric(digits.H, min = 0, single = TRUE)
@@ -804,6 +837,16 @@ settings.meta <- function(...) {
       ##
       setOption("big.mark", big.mark)
     }
+    if (!is.na(idzero.pval)) {
+      zero.pval <- args[[idzero.pval]]
+      chklogical(zero.pval)
+      setOption("zero.pval", zero.pval)
+    }
+    if (!is.na(idJAMA.pval)) {
+      JAMA.pval <- args[[idJAMA.pval]]
+      chklogical(JAMA.pval)
+      setOption("JAMA.pval", JAMA.pval)
+    }
     if (!is.na(idprint.I2)) {
       print.I2 <- args[[idprint.I2]]
       chklogical(print.I2)
@@ -826,6 +869,13 @@ settings.meta <- function(...) {
       ##
       setOption("text.tau2", text.tau2)
     }
+    if (!is.na(idtext.tau)) {
+      text.tau <- args[[idtext.tau]]
+      if (length(text.tau) != 1)
+        stop("Argument 'text.tau' must be a character string.")
+      ##
+      setOption("text.tau", text.tau)
+    }
     if (!is.na(idtext.I2)) {
       text.I2 <- args[[idtext.I2]]
       if (length(text.I2) != 1)
@@ -886,10 +936,15 @@ settings.meta <- function(...) {
       chklogical(MH.exact)
       setOption("MH.exact", MH.exact)
     }
-    if (!is.na(idRR.cochrane)) {
-      RR.cochrane <- args[[idRR.cochrane]]
-      chklogical(RR.cochrane)
-      setOption("RR.cochrane", RR.cochrane)
+    if (!is.na(idRR.Cochrane)) {
+      RR.Cochrane <- args[[idRR.Cochrane]]
+      chklogical(RR.Cochrane)
+      setOption("RR.Cochrane", RR.Cochrane)
+    }
+    if (!is.na(idQ.Cochrane)) {
+      Q.Cochrane <- args[[idQ.Cochrane]]
+      chklogical(Q.Cochrane)
+      setOption("Q.Cochrane", Q.Cochrane)
     }
     if (!is.na(idprint.CMH)) {
       print.CMH <- args[[idprint.CMH]]
